"""Tests for the templatetags of the ``multilingual_events`` app."""
from django.template import RequestContext
from django.test import TestCase, RequestFactory

from ..templatetags.multilingual_events_tags import get_events
from .factories import EventTitleFactory


class GetEventsTestCase(TestCase):
    """Tests for the ``get_events`` templatetag."""
    longMessage = True

    def test_tag(self):
        EventTitleFactory()
        EventTitleFactory()
        req = RequestFactory().get('/')
        req.LANGUAGE_CODE = 'en'
        context = RequestContext(req)
        result = get_events(context)
        self.assertEqual(result.count(), 2)

        req.LANGUAGE_CODE = None
        context = RequestContext(req)
        result = get_events(context)
        self.assertEqual(result.count(), 0, msg=(
            'When no LANGUAGE_CODE can be found, it should return an empty'
            ' QuerySet'))



"""Views for the ``multilingual_events`` app."""
from django.views.generic import DetailView, TemplateView

from .models import Event


class EventListView(TemplateView):
    """A view that lists all upcoming events for the current language."""
    template_name = 'multilingual_events/event_list.html'

    def get_context_data(self, **kwargs):
        ctx = super(EventListView, self).get_context_data(**kwargs)

        upcoming = Event.objects.get_upcoming(self.request)
        archived = Event.objects.get_archived(self.request)

        ctx.update({
            'upcoming_events': upcoming,
            'archived_events': archived,
        })
        return ctx


class EventDetailView(DetailView):
    """A view that displays detailed information about an event."""
    model = Event



"""Settings for the ``multilingual_events`` app."""
from django.conf import settings
from django.utils.translation import ugettext_lazy as _


display_type_choices = [
    ('small', _('small')),
    ('big', _('big')),
]

DISPLAY_TYPE_CHOICES = getattr(
    settings, 'EVENT_PLUGIN_DISPLAY_TYPE_CHOICES', display_type_choices)



"""CMS apphook for the ``multilingual_events`` app."""
from django.utils.translation import ugettext_lazy as _

from cms.app_base import CMSApp
from cms.apphook_pool import apphook_pool


class SimpleEventsApphook(CMSApp):
    name = _("Multilingual Events Apphook")
    urls = ["multilingual_events.urls"]


apphook_pool.register(SimpleEventsApphook)



"""Factories for the ``multilingual_events`` app."""
from django.utils.timezone import now

import factory
from django_libs.tests.factories import SimpleTranslationMixin

from ..models import (
    Event,
    EventCategory,
    EventCategoryTitle,
    EventTitle,
    EventPluginModel,
)


class EventCategoryFactory(SimpleTranslationMixin, factory.Factory):
    """Factory for the ``EventCategory`` model."""
    FACTORY_FOR = EventCategory

    slug = factory.Sequence(lambda n: 'category-{0}'.format(n))

    @staticmethod
    def _get_translation_factory_and_field():
        return (EventCategoryTitleFactory, 'category')


class EventCategoryTitleFactory(factory.Factory):
    """Factory for the ``EventCategoryTitle`` model."""
    FACTORY_FOR = EventCategoryTitle

    title = 'Category title'
    category = factory.SubFactory(EventCategoryFactory)
    language = 'en'


class BaseEventFactory(factory.Factory):
    """Factory for the ``Event`` model."""
    FACTORY_FOR = Event

    category = factory.SubFactory(EventCategoryFactory)
    start_date = factory.LazyAttribute(lambda x: now())


class EventFactory(SimpleTranslationMixin, BaseEventFactory):
    FACTORY_FOR = Event

    @staticmethod
    def _get_translation_factory_and_field():
        return (EventTitleFactory, 'event')


class EventPluginModelFactory(factory.Factory):
    """Factory for ``EventPluginModel`` objects."""
    FACTORY_FOR = EventPluginModel

    display_type = 'small'
    event = factory.SubFactory(EventFactory)


class EventTitleFactory(factory.Factory):
    """Factory for the ``EventTitle`` model."""
    FACTORY_FOR = EventTitle

    title = 'A title'
    description = 'A description'
    # we use only the BaseEventFactory here, because calling the EventFactory
    # as SubFactory will result in duplicate EventTitle objects
    event = factory.SubFactory(BaseEventFactory)
    language = 'en'
    is_published = True



"""Admin classes for the ``multilingual_event`` app."""
from django.contrib import admin
from django.utils.translation import ugettext_lazy as _

from cmsplugin_blog.admin import M2MPlaceholderAdmin
from django_libs.admin import MultilingualPublishMixin
from simple_translation.admin import TranslationAdmin

from .models import Event, EventCategory


class EventCategoryAdmin(TranslationAdmin):
    """Admin class for the ``EventCategory`` model."""
    list_display = ['title', 'languages', ]

    def title(self, obj):
        return obj.get_translation().title
    title.short_description = _('Title')


class EventAdmin(MultilingualPublishMixin, M2MPlaceholderAdmin):
    """Admin class for the ``Event`` model."""
    list_display = ['title', 'start_date', 'user', 'languages', 'is_published']

    def title(self, obj):
        return obj.get_translation().title
    title.short_description = _('Title')


admin.site.register(Event, EventAdmin)
admin.site.register(EventCategory, EventCategoryAdmin)



"""CMS plugins for the ``multilingual_events`` app."""
from django.utils.translation import ugettext_lazy as _

from cms.plugin_pool import plugin_pool
from cms.plugin_base import CMSPluginBase

from .forms import EventAgendaSessionForm, EventAgendaTalkForm
from .models import (
    EventAgendaDay,
    EventAgendaSession,
    EventAgendaTalk,
    EventPluginModel,
)


class EventAgendaDayPlugin(CMSPluginBase):
    """CMS plugin for the ``EventAgendaDay`` model."""
    model = EventAgendaDay
    name = _('Event Agenda Day')
    render_template = 'multilingual_events/plugins/event_agenda_day.html'

    def render(self, context, instance, placeholder):
        context.update({
            'object': instance,
            'placeholder': placeholder,
        })
        return context


class EventAgendaSessionPlugin(CMSPluginBase):
    """CMS plugin for the ``EventAgendaSession`` model."""
    model = EventAgendaSession
    form = EventAgendaSessionForm
    name = _('Event Agenda Session')
    render_template = 'multilingual_events/plugins/event_agenda_session.html'

    def render(self, context, instance, placeholder):
        context.update({
            'object': instance,
            'placeholder': placeholder,
        })
        return context


class EventAgendaTalkPlugin(CMSPluginBase):
    """CMS plugin for the ``EventAgendaTalk`` model."""
    model = EventAgendaTalk
    form = EventAgendaTalkForm
    name = _('Event Agenda Talk')
    render_template = 'multilingual_events/plugins/event_agenda_talk.html'

    def render(self, context, instance, placeholder):
        context.update({
            'object': instance,
            'placeholder': placeholder,
        })
        return context


class EventPlugin(CMSPluginBase):
    model = EventPluginModel
    name = _('Event Plugin')
    render_template = 'multilingual_events/event_plugin.html'

    def render(self, context, instance, placeholder):
        context.update({
            'plugin': instance,
            'event': instance.event,
        })
        return context


plugin_pool.register_plugin(EventAgendaDayPlugin)
plugin_pool.register_plugin(EventAgendaSessionPlugin)
plugin_pool.register_plugin(EventAgendaTalkPlugin)
plugin_pool.register_plugin(EventPlugin)



import os
from setuptools import setup, find_packages
import multilingual_events


def read(fname):
    try:
        return open(os.path.join(os.path.dirname(__file__), fname)).read()
    except IOError:
        return ''


setup(
    name="django-multilingual-events",
    version=multilingual_events.__version__,
    description=read('DESCRIPTION'),
    long_description=read('README.rst'),
    license='The MIT License',
    platforms=['OS Independent'],
    keywords='django, event, i18n, simple-translation, multilingual',
    author='Martin Brochhaus',
    author_email='mbrochh@gmail.com',
    url="https://github.com/bitmazk/django-multilingnual-events",
    packages=find_packages(),
    include_package_data=True,
    tests_require=[
        'fabric',
        'factory_boy',
        'django-nose',
        'coverage',
        'django-coverage',
        'mock',
    ],
    test_suite='multilingual_events.tests.runtests.runtests',
)
